==> cms-db_v0.6.tar.gz: admin/locale.inc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

class LocalizingClass {

	protected $filename;
	protected $count = 0;
	protected $time_start;
	public $langcode;
	public $locale = array();

	//function __construct( $filename, $langcode = $_SESSION['CMS-Locale'], $path_before = './' ) {
	function __construct( $filename, $langcode = 'SESSION', $path_before = './' ) {
		$time_start = microtime(true);
		//echo '<!--Intializing LocalizingClass...-->';
		if ($langcode == 'SESSION') {
			$langcode = $_SESSION['CMS-Locale'];
			//echo '<!--LocalizingClass: loading language code from $_SESSION-->';
		}
		if (!file_exists($path_before.'locales/'.$langcode.'/locale_'.$filename.'.php')) {
			echo '<html><head><title>cms -db LocalizingClass</title></head><body>
<strong>cms -db</strong><br>
Fatal Error: Sorry, I couldn\'t find the locale file.<br>
A reason for this could be that your locale set doesn\'t contain translations for this file.<br><br>
<u>Useful Information for debugging:</u><br>
<i>File:</i> '.$path_before.'locales/'.$langcode.'/locale_'.$filename.'.php<br>
<i>Path before:</i> '.$path_before.'<br>
<i>Language code:</i> '.$langcode.'<br>
<i>File name:</i> '.$filename.'</body></html>';
			die();
		}
		include( $path_before.'locales/'.$langcode.'/common.php' );
		include( $path_before.'locales/'.$langcode.'/locale_'.$filename.'.php' );
		$this->filename = $filename;
		$this->locale = $locale;
		$this->time_start = $time_start;
		$this->langcode = $langcode;
		//echo '<!--Intialized LocalizingClass.-->';
	}
	
	function __destruct() {
		$time_now = microtime(true);
		$time = $time_now - $this->time_start;
		# We would display the report, but Internet Explorer falls back
		# to quirks mode on the website because this is displayed before
		# the doctype there.
		/*echo '<!-- cms -db LocalizingClass report
Replaced strings: '.$this->count.'
Runtime (in s): '.$time.' -->';*/
		//echo '<!--LocalizingClass was killed.-->';
	}

	public function getLocalizedText( $which ) {
		if ( isset( $this->locale[$this->filename][$which] ) ) {
			$text = $this->locale[$this->filename][$which];
		} else if ( isset( $this->locale['common'][$which] ) ) {
			$text = $this->locale['common'][$which];
		} else {
			$text = 'Localized text not found: '.$which;
		}
		$this->count++;
		return $text;
	}

	public function printLocalizedText( $which ) {
		echo $this->getLocalizedText( $which );
	}

}

/* helper function for getting localized text */
function locale($text, $return = false, $locale = false) {
	if ($locale == false) {
		global $locale;
	}
	if ($return != true) {
		$locale->printLocalizedText($text);
		return true;
	} else {
		return $locale->getLocalizedText($text);
	}
}
?>

==> cms-db_v0.7.5.tar.gz: admin/locale.inc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

class LocalizingClass {

	protected $filename;
	protected $count = 0;
	protected $time_start;
	public $langcode;
	public $locale = array();

	//function __construct( $filename, $langcode = $_SESSION['CMS-Locale'], $path_before = './' ) {
	function __construct( $filename, $langcode = 'SESSION', $path_before = './' ) {
		$time_start = microtime(true);
		//echo '<!--Intializing LocalizingClass...-->';
		if ($langcode == 'SESSION') {
			$langcode = $_SESSION['CMS-Locale'];
			//echo '<!--LocalizingClass: loading language code from $_SESSION-->';
		}
		if (!file_exists($path_before.'locales/'.$langcode.'/locale_'.$filename.'.php')) {
			header('Content-type: text/html');
			echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
	"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title>cms -db LocalizingClass</title>
		<meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
		<style type="text/css">/* <![CDATA[ */
		html { padding: 0; margin: 0; }
		body { font-family: "Bitstream Vera Sans", Arial, Helvetica sans-serif;
			font-size: 10pt; padding: 0; margin: 1em; background: #eee; color: #000; }
		h1 { font-size: 4em; margin: -.25em -.25em 0 -.25em; padding: .25em;
			background: #ddd; border-bottom: .1em solid #bbb; font-weight: normal; color: #032b4f; }
		h3 { font-size: 1em; text-decoration: underline; font-weight: normal; }
		/* ]]> */</style>
	</head>
	<body>
		<h1>cms -db</h1>
		<h2>LocalizingClass Error</h2>
		<p>Unable to find the locale file.</p>
		<p>A reason for this could be that your locale set doesn\'t contain translations for this file.</p>
		<h3>Useful Information for debugging:</h3>
		<p>
			<i>File:</i> '.$path_before.'locales/'.$langcode.'/locale_'.$filename.'.php<br />
			<i>Path before:</i> '.$path_before.'<br />
			<i>Language code:</i> '.$langcode.'<br />
			<i>File name:</i> '.$filename.'
		</p>
	</body>
</html>';
			die();
		}
		include( $path_before.'locales/'.$langcode.'/common.php' );
		include( $path_before.'locales/'.$langcode.'/locale_'.$filename.'.php' );
		$this->filename = $filename;
		$this->locale = $locale;
		$this->time_start = $time_start;
		$this->langcode = $langcode;
		//echo '<!--Intialized LocalizingClass.-->';
	}
	
	function __destruct() {
		$time_now = microtime(true);
		$time = $time_now - $this->time_start;
		# We would display the report, but Internet Explorer falls back
		# to quirks mode on the website because this is displayed before
		# the doctype there.
		/*echo '<!-- cms -db LocalizingClass report
Replaced strings: '.$this->count.'
Runtime (in s): '.$time.' -->';*/
		//echo '<!--LocalizingClass was killed.-->';
	}

	public function getLocalizedText( $which ) {
		if ( isset( $this->locale[$this->filename][$which] ) ) {
			$text = $this->locale[$this->filename][$which];
		} else if ( isset( $this->locale['common'][$which] ) ) {
			$text = $this->locale['common'][$which];
		} else {
			$text = 'Localized text not found: '.$which;
		}
		$this->count++;
		return $text;
	}

	public function printLocalizedText( $which ) {
		echo $this->getLocalizedText( $which );
	}

}

/* helper function for getting localized text */
function locale($text, $return = false, $locale = false) {
	if ($locale == false) {
		global $locale;
	}
	if ($return != true) {
		$locale->printLocalizedText($text);
		return true;
	} else {
		return $locale->getLocalizedText($text);
	}
}
?>
